=====
Order
=====

The order app handles processing of orders.

Abstract models
---------------

.. automodule:: oscar.apps.order.abstract_models
    :members:
    :noindex:

Order processing
----------------

.. automodule:: oscar.apps.order.processing
    :members:

Utils
-----

.. automodule:: oscar.apps.order.utils
    :members:
